Enum mailparse::DispositionType
source · pub enum DispositionType {
Inline,
Attachment,
FormData,
Extension(String),
}Expand description
The possible disposition types in a Content-Disposition header. A more
comprehensive list of IANA-recognized types can be found at
https://www.iana.org/assignments/cont-disp/cont-disp.xhtml. This library
only enumerates the types most commonly found in email messages, and
provides the Extension value for holding all other types.
Variants
Inline
Default value, indicating the content is to be displayed inline as part of the enclosing document.
Attachment
A disposition indicating the content is not meant for inline display, but whose content can be accessed for use.
FormData
A disposition indicating the content contains a form submission.
Extension(String)
Extension type to hold any disposition not explicitly enumerated.