Enum mailparse::MailAddr [−][src]
pub enum MailAddr {
Group(GroupInfo),
Single(SingleInfo),
}An abstraction over the two different kinds of top-level addresses allowed in email headers. Group addresses have a name and a list of mailboxes. Single addresses are just a mailbox. Each mailbox consists of what you would consider an email address (e.g. foo@bar.com) and optionally a display name (“Foo Bar”). Groups are represented in email headers with colons and semicolons, e.g. To: my-peeps: foo@peeps.org, bar@peeps.org;
Variants
Group(GroupInfo)Single(SingleInfo)Trait Implementations
impl StructuralPartialEq for MailAddr[src]
impl StructuralPartialEq for MailAddr[src]Auto Trait Implementations
impl RefUnwindSafe for MailAddr
impl RefUnwindSafe for MailAddrimpl UnwindSafe for MailAddr
impl UnwindSafe for MailAddr