Struct mailparse::body::BinaryBody [−][src]
Struct that holds a binary body representation of the message (or message subpart).
Implementations
impl<'a> BinaryBody<'a>[src]
pub fn get_content_type(&self) -> &'a ParsedContentType[src]
Get the body Content-Type
pub fn get_raw(&self) -> &'a [u8]ⓘ[src]
Get the raw body of the message exactly as it is written in the message (or message subpart).
pub fn get_as_string(&self) -> Result<String, MailParseError>[src]
Get the body of the message as a Rust string. This function attempts to convert the body into a Rust UTF-8 string using the charset in the Content-Type header (or "us-ascii" as default). However, this may not always work for "binary" data. The API is provided anyway for convenient handling of real-world emails that may provide textual data with a binary transfer encoding, but use this at your own risk!